# Integrations

Framework integrations are the main way to use *svcs*.
Thanks to its flexibility, it's possible to integrate with any framework in their own most idiosyncratic way.

*svcs* currently integrates out-of-the-box with the following ones:

```{toctree}
:maxdepth: 1

aiohttp
fastapi
flask
pyramid
starlette
```

But it's also straight-forward to [write your own](custom.md)!

```{toctree}
:hidden:
custom
```
